# coding: utf-8

"""
    Weheat Backend

    This is the backend for the Weheat project

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
import pprint
import re  # noqa: F401
from enum import Enum



try:
    from typing import Self
except ImportError:
    from typing_extensions import Self


class DeviceState(int, Enum):
    """
    State of the device:   - ProductionObsoleteState (0),   - InStock (1),   - Sold (2),   - Active (3),   - Inactive (4),   - Broken (5),   - Test (6)   - Configured (7)  For now Production, InStock and Sold will only be applicable to Devices that can be actually installed in installation
    """

    """
    allowed enum values
    """
    NUMBER_0 = 0
    NUMBER_1 = 1
    NUMBER_2 = 2
    NUMBER_3 = 3
    NUMBER_4 = 4
    NUMBER_5 = 5
    NUMBER_6 = 6
    NUMBER_7 = 7

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of DeviceState from a JSON string"""
        return cls(json.loads(json_str))


