# coding: utf-8

"""
    Weheat Backend

    This is the backend for the Weheat project

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
import pprint
import re  # noqa: F401
from enum import Enum



try:
    from typing import Self
except ImportError:
    from typing_extensions import Self


class BoilerType(int, Enum):
    """
    Type of model and use of the heat pump   - Unknown: Not known if a boiler is in the installation (0)   - None: No boiler detected (1)   - OnOff: On/off boiler detected (2)   - OpenTherm: OpenTherm boiler detected (3)
    """

    """
    allowed enum values
    """
    NUMBER_0 = 0
    NUMBER_1 = 1
    NUMBER_2 = 2
    NUMBER_3 = 3

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of BoilerType from a JSON string"""
        return cls(json.loads(json_str))


